Struct StdioInput
Source pub struct StdioInput { }
Tokio-based stdin reader.
Read one line (terminator stripped) into
buf.
Ok(None) on EOF.
Err on overflow (line > buf.len()) or invalid UTF-8.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.